@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 from django.contrib import admin
 from django import forms
-from coop.exchange.models import BaseExchange, BasePaymentModality, BaseTransaction, BaseProduct
+from coop.exchange.models import BaseTransaction, BaseProduct
 
 from django.db.models.loading import get_model
 from django.utils.translation import ugettext_lazy as _
@@ -9,33 +9,52 @@ from coop.utils.autocomplete_admin import FkAutocompleteAdmin, InlineAutocomplet
 from django_extensions.admin import ForeignKeyAutocompleteAdmin
 from coop_geo.admin import LocatedInline
 from tinymce.widgets import AdminTinyMCE
+from coop.utils.fields import MultiSelectFormField, MethodsCheckboxSelectMultiple, DomainCheckboxSelectMultiple
+from coop.exchange.models import ETYPE
+
+# class PaymentInline(admin.TabularInline):
+#     model = get_model('coop_local', 'PaymentModality')
+#     #model = BasePaymentModality
+#     extra = 0
 
 
-class PaymentInline(admin.TabularInline):
-    model = get_model('coop_local', 'PaymentModality')
-    #model = BasePaymentModality
-    extra = 0
+class ExchangeMethodForm(forms.ModelForm):
+    etypes = MultiSelectFormField(widget=DomainCheckboxSelectMultiple(), choices=ETYPE.CHOICES)
+
+    class Meta:
+        model = get_model('coop_local', 'ExchangeMethod')
+
+
+class ExchangeMethodAdmin(admin.ModelAdmin):  # AdminImageMixin,
+    form = ExchangeMethodForm
+    list_display = ('label', 'applications')
 
 
 class ExchangeForm(forms.ModelForm):
     description = forms.CharField(widget=AdminTinyMCE(attrs={'cols': 80, 'rows': 60}), required=False)
+    #methods = forms.ModelMultipleChoiceField(widget=forms.CheckboxSelectMultiple())
+    
+    def __init__(self, *args, **kwargs):
+        super(ExchangeForm, self).__init__(*args, **kwargs)
+    #    self.fields['methods'].widget = forms.CheckboxSelectMultiple()
+        self.fields['methods'].help_text = ''
 
+    class Media:
+        js = ('js/select_exchange_methods.js',)
+        
     class Meta:
         model = get_model('coop_local', 'Exchange')
+        widgets = {
+            'methods': MethodsCheckboxSelectMultiple()
+        }
 
 
 class ExchangeInline(admin.StackedInline):
     form = ExchangeForm
     model = get_model('coop_local', 'Exchange')
-    # verbose_name = _(u'Exchange')
-    # verbose_name_plural = _(u'Exchanges')
-    #form = ExchangeInlineLinkForm 
-    # needed to include a link to the change_form / only because nested inlines are not possible
-    fieldsets = ((None, {'fields': ('title',
-                                    ('eway','etype'), 
-                                    ('mod_euro', 'mod_free', 'mod_troc', 
-                                     'mod_mutu', 'mod_mc', 'mod_job', 
-                                     'mod_stage', 'mod_benevolat', 'mod_volontariat'),
+    fieldsets = ((None, {'fields': (('eway', 'etype'),
+                                     'methods',
+                                     'title',
                                     'description', 'tags')
                         }),)
 
@@ -60,13 +79,17 @@ class TransactionInline(admin.StackedInline):
 
 
 class ExchangeAdmin(ForeignKeyAutocompleteAdmin):  # AdminImageMixin,
-    fieldsets = ((None, {
-            'fields': (('etype', 'permanent', 'expiration', ), 'title', 'description',
-                       'organization'
-                       )
-            }),)
+    form = ExchangeForm
+    list_display = ('title', 'etype', 'methods')
+    list_editable = ('methods',)
     related_search_fields = {'organization': ('title', 'subtitle', 'description'), }
+    fieldsets = ((None, {'fields': (('eway', 'etype'),
+                                     'methods',
+                                     'title',
+                                     'organization',
+                                    'description', 'tags')
+                        }),)
     inlines = [
-            PaymentInline,
+            #PaymentInline,
             LocatedInline,  # Using coop-geo
         ]
