@@ -1,14 +1,15 @@
 # -*- coding:utf-8 -*-
 
 from django.utils.translation import ugettext_lazy as _
-from django.contrib.syndication.views import Feed
+#from django.contrib.syndication.views import Feed
 from coop_local.models import Organization
 from django.contrib.sites.models import Site
+from django_push.publisher.feeds import Feed
 
 
 class OrganizationUpdates(Feed):
     title = _(u"Organization updates for %s." % Site.objects.get_current().name)
-    link = "/org-updates/"
+    link = "/organizations/"
     description = _(u"All records updates for organizations listed on the %s website." % Site.objects.get_current().name)
 
     def items(self):
